==> ore.svn-1.0.0.tar.gz: ore.svn-1.0.0/src/ore/svn/interfaces.py <==
####################################################################
#    ore.svn
#    Copyright (C) 2002-2006 kapil thangavelu <k_vertigo@objectrealms.net>
#    Copyright (C) 2006 ObjectRealms, LLC
#
#    This product is free software; you can redistribute it and/or
#    modify it under the terms of the GNU Lesser General Public
#    License as published by the Free Software Foundation; either
#    version 2.1 of the License, or (at your option) any later version.
#
#    This product is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
#    Lesser General Public License for more details.
#
#    You should have received a copy of the GNU Lesser General Public
#    License along with this product; if not, write to the Free Software
#    Foundation, Inc., 59 Temple Place, Suite
####################################################################

"""
$Id: interfaces.py 1544 2006-08-15 00:56:07Z hazmat $
"""

## from zope import schema
from zope.interface import Interface
## from zope.app.location import ILocation
## from zope.app.filerepresentation.interfaces import IReadFile, IWriteFile
## from zope.app.container.interfaces import IReadContainer

#################################
# Exceptions

class InvalidRepositoryPath(Exception): pass
class RootPathViolation(Exception): pass
class UnsupportedNodeType(Exception): pass

#################################
# Globals
DEBUG = 0
CHUNK_SIZE = 16384
_marker = object()
HEAD = 0

class ISubversionNode( Interface ):

    #node_id = schema.ASCIILine("node_id", "Subversion Node Id")


    def getModificationTime():
        """
        """

    def getProperty( property_name ):
        """
        """

    def getProperties():
        """
        """

    def getRevisionPathMap():
        """
        """

    def getRevisionCreated():
        """
        """

    def getMappedLogEntries():
        """
        """

    def getLog( revision=HEAD):
        """
        """


class ISubversionFile( ISubversionNode ):

    def isBinary():
        """
        """

    def getMimeType():
        """
        """

    def getContents( revision=None, writer=None):
        """
        """

    def getSize():
        """
        """

    def getAnnotatedLines( revision_set=(), include_copies=True):
        """
        """

    def lock():
        """
        lock the node
        """

    def unlock():
        """
        unlock the node
        """

class ISubversionDirectory( ISubversionNode ):
    """
    """

class ISubversionContext( Interface ):
    pass

class IPropertySheet( Interface ): pass
class ISubversionProperties( IPropertySheet ): pass

## class ILogCollection( IReadContainer ):
##     """
##     a collection of log items
##     """


class ILogEntry( Interface ):
    pass

##     author = schema.ASCIILine( title=u"author", description=u"Author of the Revision")
##     message = schema.ASCIILine( title=u"message", description=u"Commit Message")
##     date = schema.Datetime( title=u"date", description=u"Date of the Revision")
##     revision = schema.Int( title=u"revision", description=u"Revision Number")
##     paths = schema.List( value_type=schema.ASCIILine(),
##                          required=False,
##                          unique=True)

class ILogFormatter( Interface ):

    def __call__( text ):
        """
        return text formatted
        """

## class ISubversionReadContainer( IReadContainer, ISubversionNode ):
##     pass


## class ISubversionRepository( ISubversionReadContainer ):
##     pass

##     repository_path = schema.ASCIILine( title=u"repository_path", description=u"Path to a Repository")

##     svn_path = schema.ASCIILine( title=u"svn_path", description=u"Root Path Within a Repository")

==> ore.svn-1.0.5.tar.gz: ore.svn-1.0.5/src/ore/svn/interfaces.py <==
####################################################################
# Copyright 2002-2008 Kapil Thangavelu <kapil.foss@gmail.com>
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
####################################################################
"""
$Id: interfaces.py 2205 2008-05-07 19:44:27Z hazmat $
"""
from zope.interface import Interface

#################################
# Exceptions

class InvalidRepositoryPath(Exception): pass
class RootPathViolation(Exception): pass
class UnsupportedNodeType(Exception): pass
class NoTransaction(Exception): pass

#################################
# Globals
DEBUG = 0
CHUNK_SIZE = 16384
_marker = object()
HEAD = 0

class ISubversionNode( Interface ):

    #node_id = schema.ASCIILine("node_id", "Subversion Node Id")


    def getModificationTime():
        """
        """

    def getProperty( property_name ):
        """
        """

    def getProperties():
        """
        """

    def getRevisionPathMap():
        """
        """

    def getRevisionCreated():
        """
        """

    def getMappedLogEntries():
        """
        """

    def getLog( revision=HEAD):
        """
        """


class ISubversionFile( ISubversionNode ):

    def isBinary():
        """
        """

    def getMimeType():
        """
        """

    def getContents( revision=None, writer=None):
        """
        """

    def getSize():
        """
        """

    def getAnnotatedLines( revision_set=(), include_copies=True):
        """
        """

    def lock():
        """
        lock the node
        """

    def unlock():
        """
        unlock the node
        """

class ISubversionDirectory( ISubversionNode ):
    """
    """

class ISubversionContext( Interface ):
    pass

class IPropertySheet( Interface ): pass
class ISubversionProperties( IPropertySheet ): pass

class ILogEntry( Interface ):
    pass

##     author = schema.ASCIILine( title=u"author", description=u"Author of the Revision")
##     message = schema.ASCIILine( title=u"message", description=u"Commit Message")
##     date = schema.Datetime( title=u"date", description=u"Date of the Revision")
##     revision = schema.Int( title=u"revision", description=u"Revision Number")
##     paths = schema.List( value_type=schema.ASCIILine(),
##                          required=False,
##                          unique=True)

class ILogFormatter( Interface ):

    def __call__( text ):
        """
        return text formatted
        """
